@@ -19,11 +19,9 @@
 
 function main(pass)
 {
-    var res = JsonLd.newFlightReservation();
-    res.reservationFor.departureGate = pass.field["gate"].value;
+    var res = Context.data[0];
     res.reservationFor.departureAirport.name = pass.field["origin"].label;
     res.reservationFor.arrivalAirport.name = pass.field["destination"].label;
-    res.reservationFor.boardingTime = JsonLd.toDateTime(pass.field["departureDate"].value + ' ' + pass.field["boarding"].value, "M/d/yyyy hh:mm", "en");
     if (pass.field["operatingcarrier"])
         res.reservationFor.airline.name = pass.field["operatingcarrier"].value;
 
